@@ -2,6 +2,7 @@
 import asyncio
 from enum import Enum
 from functools import partial
+import logging
 
 from xknx.exceptions import ConversionError
 from xknx.remote_value import RemoteValue
@@ -9,6 +10,8 @@ from xknx.telegram import GroupAddress
 
 DEFAULT_UPDATE_INTERVAL = 60
 
+logger = logging.getLogger("xknx.state_updater")
+
 
 class StateUpdater:
     """Class for keeping the states of RemoteValues up to date."""
@@ -41,9 +44,12 @@ class StateUpdater:
                 elif _options[0].upper() == "EVERY":
                     tracker_type = StateTrackerType.PERIODICALLY
                 else:
-                    self.xknx.logger.warning(
-                        'Could not parse StateUpdater tracker_options "%s" for %s. Using default %s %s minutes.'
-                        % (tracker_options, remote_value, tracker_type, update_interval)
+                    logger.warning(
+                        'Could not parse StateUpdater tracker_options "%s" for %s. Using default %s %s minutes.',
+                        tracker_options,
+                        remote_value,
+                        tracker_type,
+                        update_interval,
                     )
                     return (tracker_type, update_interval)
                 try:
@@ -52,15 +58,13 @@ class StateUpdater:
                 except IndexError:
                     pass  # No time given (no _options[1])
             else:
-                self.xknx.logger.warning(
-                    'Could not parse StateUpdater tracker_options type %s "%s" for %s. Using default %s %s minutes.'
-                    % (
-                        type(tracker_options),
-                        tracker_options,
-                        remote_value,
-                        tracker_type,
-                        update_interval,
-                    )
+                logger.warning(
+                    'Could not parse StateUpdater tracker_options type %s "%s" for %s. Using default %s %s minutes.',
+                    type(tracker_options),
+                    tracker_options,
+                    remote_value,
+                    tracker_type,
+                    update_interval,
                 )
             return (tracker_type, update_interval)
 
@@ -76,8 +80,11 @@ class StateUpdater:
         )
         self._workers[id(remote_value)] = tracker
 
-        self.xknx.logger.debug(
-            f"StateUpdater registered {tracker_type} {update_inteval} for {remote_value}"
+        logger.debug(
+            "StateUpdater registered %s %s for %s",
+            tracker_type,
+            update_inteval,
+            remote_value,
         )
         if self.started:
             tracker.start()
@@ -93,14 +100,14 @@ class StateUpdater:
 
     def start(self):
         """Start StateUpdater. Initialize states."""
-        self.xknx.logger.debug("StateUpdater initializing values")
+        logger.debug("StateUpdater initializing values")
         self.started = True
         for worker in self._workers.values():
             worker.start()
 
     def stop(self):
         """Stop StateUpdater."""
-        self.xknx.logger.debug("StateUpdater stopping")
+        logger.debug("StateUpdater stopping")
         self.started = False
         for worker in self._workers.values():
             worker.stop()
@@ -148,9 +155,11 @@ class _StateTracker:
 
     def start(self):
         """Start StateTracker - read state on call."""
-        self.xknx.logger.debug(
-            "StateUpdater initializing %s for %s - %s"
-            % (self.group_address, self.device_name, self.feature_name)
+        logger.debug(
+            "StateUpdater initializing %s for %s - %s",
+            self.group_address,
+            self.device_name,
+            self.feature_name,
         )
         if self.tracker_type is not StateTrackerType.INIT:
             self._start_waiting()
@@ -158,7 +167,7 @@ class _StateTracker:
 
     def _start_waiting(self):
         """Start StateTracker - wait for value to expire."""
-        self._task = self.xknx.loop.create_task(self._update_loop())
+        self._task = asyncio.create_task(self._update_loop())
 
     def stop(self):
         """Stop StateTracker."""
@@ -189,8 +198,10 @@ class _StateTracker:
 
     def _read_state(self):
         """Schedule to read the state from the KNX bus."""
-        self.xknx.logger.debug(
-            "StateUpdater scheduled reading %s for %s - %s"
-            % (self.group_address, self.device_name, self.feature_name)
+        logger.debug(
+            "StateUpdater scheduled reading %s for %s - %s",
+            self.group_address,
+            self.device_name,
+            self.feature_name,
         )
-        self.xknx.loop.create_task(self._read_state_awaitable())
+        asyncio.create_task(self._read_state_awaitable())
