@@ -7,11 +7,13 @@ The module will
 * ... check if received telegrams have the correct group address.
 * ... store the received telegram for further processing.
 """
-
 import asyncio
+import logging
 
 from xknx.telegram import Telegram, TelegramType
 
+logger = logging.getLogger("xknx.log")
+
 
 class ValueReader:
     """Class for reading the value of a specific KNX group address from KNX bus."""
@@ -65,7 +67,7 @@ class ValueReader:
 
     def timeout(self):
         """Handle timeout for not having received expected group response."""
-        self.xknx.logger.warning(
+        logger.warning(
             "Error: KNX bus did not respond in time (%s secs) to GroupValueRead request for: %s",
             self.timeout_in_seconds,
             self.group_address,
@@ -74,9 +76,8 @@ class ValueReader:
 
     async def start_timeout(self):
         """Start timeout. Register callback for no answer received within timeout."""
-        self.timeout_handle = self.xknx.loop.call_later(
-            self.timeout_in_seconds, self.timeout
-        )
+        loop = asyncio.get_running_loop()
+        self.timeout_handle = loop.call_later(self.timeout_in_seconds, self.timeout)
 
     async def stop_timeout(self):
         """Stop timeout."""
