@@ -7,6 +7,8 @@ It provides functionality for
 * reading the current state from KNX bus.
 * Cover will also predict the current position.
 """
+import logging
+
 from xknx.remote_value import (
     RemoteValueScaling,
     RemoteValueStep,
@@ -17,6 +19,8 @@ from xknx.remote_value import (
 from .device import Device
 from .travelcalculator import TravelCalculator
 
+logger = logging.getLogger("xknx.log")
+
 
 class Cover(Device):
     """Class for managing a cover."""
@@ -53,7 +57,11 @@ class Cover(Device):
         # travelcalculator (in process_group_write and set_*) - angle changes
         # are updated from RemoteValue objects
         self.updown = RemoteValueUpDown(
-            xknx, group_address_long, device_name=self.name, after_update_cb=None
+            xknx,
+            group_address_long,
+            device_name=self.name,
+            after_update_cb=None,
+            invert=invert_position,
         )
 
         self.step = RemoteValueStep(
@@ -61,6 +69,7 @@ class Cover(Device):
             group_address_short,
             device_name=self.name,
             after_update_cb=self.after_update,
+            invert=invert_position,
         )
 
         self.stop_ = RemoteValueSwitch(
@@ -185,9 +194,7 @@ class Cover(Device):
         elif self.step.writable:
             await self.step.increase()
         else:
-            self.xknx.logger.warning(
-                "Stop not supported for device %s", self.get_name()
-            )
+            logger.warning("Stop not supported for device %s", self.get_name())
             return
         self.travelcalculator.stop()
         await self.after_update()
@@ -204,7 +211,7 @@ class Cover(Device):
                 elif position == self.travelcalculator.position_closed:
                     await self.updown.down()
                 else:
-                    self.xknx.logger.warning(
+                    logger.warning(
                         "Current position unknown. Initialize cover by moving to end position."
                     )
                     return
@@ -220,9 +227,7 @@ class Cover(Device):
     async def set_angle(self, angle):
         """Move cover to designated angle."""
         if not self.supports_angle:
-            self.xknx.logger.warning(
-                "Angle not supported for device %s", self.get_name()
-            )
+            logger.warning("Angle not supported for device %s", self.get_name())
             return
         await self.angle.set(angle)
 
@@ -254,7 +259,7 @@ class Cover(Device):
         elif action == "stop":
             await self.stop()
         else:
-            self.xknx.logger.warning(
+            logger.warning(
                 "Could not understand action %s for device %s", action, self.get_name()
             )
 
@@ -264,7 +269,7 @@ class Cover(Device):
         await self.angle.read_state(wait_for_result=wait_for_result)
 
     async def process_group_write(self, telegram):
-        """Process incoming GROUP WRITE telegram."""
+        """Process incoming and outgoing GROUP WRITE telegram."""
         if await self.updown.process(telegram):
             if self.updown.value == RemoteValueUpDown.Direction.UP:
                 self.travelcalculator.start_travel_up()
