@@ -6,10 +6,14 @@ It provides functionality for
 * setting fan to specific speed
 * reading the current speed from KNX bus.
 """
+import logging
+
 from xknx.remote_value import RemoteValueScaling
 
 from .device import Device
 
+logger = logging.getLogger("xknx.log")
+
 
 class Fan(Device):
     """Class for managing a fan."""
@@ -72,12 +76,12 @@ class Fan(Device):
         if action.startswith("speed:"):
             await self.set_speed(int(action[6:]))
         else:
-            self.xknx.logger.warning(
+            logger.warning(
                 "Could not understand action %s for device %s", action, self.get_name()
             )
 
     async def process_group_write(self, telegram):
-        """Process incoming GROUP WRITE telegram."""
+        """Process incoming and outgoing GROUP WRITE telegram."""
         await self.speed.process(telegram)
 
     @property
