@@ -6,10 +6,14 @@ It provides functionality for
 * switching 'on' and 'off'.
 * reading the current state from KNX bus.
 """
+import logging
+
 from xknx.remote_value import RemoteValueSwitch
 
 from .device import Device
 
+logger = logging.getLogger("xknx.log")
+
 
 class Switch(Device):
     """Class for managing a switch."""
@@ -72,12 +76,12 @@ class Switch(Device):
         elif action == "off":
             await self.set_off()
         else:
-            self.xknx.logger.warning(
+            logger.warning(
                 "Could not understand action %s for device %s", action, self.get_name()
             )
 
     async def process_group_write(self, telegram):
-        """Process incoming GROUP WRITE telegram."""
+        """Process incoming and outgoing GROUP WRITE telegram."""
         await self.switch.process(telegram)
 
     def __str__(self):
