@@ -4,9 +4,16 @@ Abstraction for handling KNX/IP tunnels.
 Tunnels connect to KNX/IP devices directly via UDP and build a static UDP connection.
 """
 import asyncio
+import logging
 
 from xknx.exceptions import CommunicationError, XKNXException
-from xknx.knxip import CEMIMessageCode, KNXIPFrame, KNXIPServiceType, TunnellingRequest
+from xknx.knxip import (
+    CEMIMessageCode,
+    KNXIPFrame,
+    KNXIPServiceType,
+    TunnellingAck,
+    TunnellingRequest,
+)
 from xknx.telegram import PhysicalAddress, TelegramDirection
 
 from .connect import Connect
@@ -15,6 +22,8 @@ from .disconnect import Disconnect
 from .tunnelling import Tunnelling
 from .udp_client import UDPClient
 
+logger = logging.getLogger("xknx.log")
+
 
 class Tunnel:
     """Class for handling KNX/IP tunnels."""
@@ -69,7 +78,7 @@ class Tunnel:
         """Handle incoming tunnel request."""
         # pylint: disable=unused-argument
         if knxipframe.header.service_type_ident != KNXIPServiceType.TUNNELLING_REQUEST:
-            self.xknx.logger.warning("Service not implemented: %s", knxipframe)
+            logger.warning("Service not implemented: %s", knxipframe)
         else:
             self.send_ack(
                 knxipframe.body.communication_channel_id,
@@ -88,12 +97,12 @@ class Tunnel:
 
     def send_ack(self, communication_channel_id, sequence_counter):
         """Send tunnelling ACK after tunnelling request received."""
-        ack_knxipframe = KNXIPFrame(self.xknx)
-        ack_knxipframe.init(KNXIPServiceType.TUNNELLING_ACK)
-        ack_knxipframe.body.communication_channel_id = communication_channel_id
-        ack_knxipframe.body.sequence_counter = sequence_counter
-        ack_knxipframe.normalize()
-        self.udp_client.send(ack_knxipframe)
+        ack = TunnellingAck(
+            self.xknx,
+            communication_channel_id=communication_channel_id,
+            sequence_counter=sequence_counter,
+        )
+        self.udp_client.send(KNXIPFrame.init_from_body(ack))
 
     async def start(self):
         """Start tunneling."""
@@ -110,23 +119,22 @@ class Tunnel:
         await connect.start()
         if not connect.success:
             if self.auto_reconnect:
-                msg = "Could not connect to KNX. Retry in {} seconds.".format(
-                    self.auto_reconnect_wait
+                logger.warning(
+                    "Could not connect to KNX. Retry in %s seconds.",
+                    self.auto_reconnect_wait,
                 )
-                self.xknx.logger.warning(msg)
-                task = self.xknx.loop.create_task(self.schedule_reconnect())
-                self._reconnect_task = task
+                self._reconnect_task = asyncio.create_task(self.schedule_reconnect())
                 return
             raise CommunicationError(
                 "Could not establish connection", not self._is_reconnecting
             )
-        self.xknx.logger.debug(
+        logger.debug(
             "Tunnel established communication_channel=%s, id=%s",
             connect.communication_channel,
             connect.identifier,
         )
         if self._is_reconnecting:
-            self.xknx.logger.info("Successfully reconnected to KNX bus.")
+            logger.info("Successfully reconnected to KNX bus.")
         self._reconnect_task = None
         self._is_reconnecting = False
         self.communication_channel = connect.communication_channel
@@ -152,14 +160,10 @@ class Tunnel:
         """
         success = await self._send_telegram_impl(telegram)
         if not success:
-            self.xknx.logger.debug(
-                "Sending of telegram failed. Retrying a second time."
-            )
+            logger.debug("Sending of telegram failed. Retrying a second time.")
             success = await self._send_telegram_impl(telegram)
             if not success:
-                self.xknx.logger.debug(
-                    "Resending telegram failed. Reconnecting to tunnel."
-                )
+                logger.debug("Resending telegram failed. Reconnecting to tunnel.")
                 await self.reconnect()
                 success = await self._send_telegram_impl(telegram)
                 if not success:
@@ -212,7 +216,7 @@ class Tunnel:
         await disconnect.start()
         if not disconnect.success and not ignore_error:
             raise XKNXException("Could not disconnect channel")
-        self.xknx.logger.debug(
+        logger.debug(
             "Tunnel disconnected (communication_channel: %s)",
             self.communication_channel,
         )
@@ -222,6 +226,7 @@ class Tunnel:
     async def reconnect(self):
         """Reconnect to tunnel device."""
         self._is_reconnecting = True
+        await self.stop_heartbeat()
         await self.disconnect(True)
         self.init_udp_client()
         await self.start()
@@ -249,7 +254,7 @@ class Tunnel:
 
     async def start_heartbeat(self):
         """Start heartbeat for monitoring state of tunnel, as suggested by 03.08.02 KNX Core 5.4."""
-        self._heartbeat_task = self.xknx.loop.create_task(self.do_heartbeat())
+        self._heartbeat_task = asyncio.create_task(self.do_heartbeat())
 
     async def stop_heartbeat(self):
         """Stop heartbeat task if running."""
@@ -280,7 +285,7 @@ class Tunnel:
         self.number_heartbeat_failed = self.number_heartbeat_failed + 1
         if self.number_heartbeat_failed > 3:
             if not self._is_reconnecting:
-                self.xknx.logger.warning("Heartbeat to KNX bus failed. Reconnecting.")
+                logger.warning("Heartbeat to KNX bus failed. Reconnecting.")
             try:
                 await self.stop_reconnect()
                 await self.reconnect()
@@ -288,4 +293,4 @@ class Tunnel:
                 await self.stop_heartbeat()
             except CommunicationError as exc:
                 if exc.should_log:
-                    self.xknx.logger.warning(exc)
+                    logger.warning(exc)
