@@ -3,12 +3,16 @@ Module for Serialization and Deserialization of a KNX Tunnelling Request informa
 
 Tunnelling requests are used to transmit a KNX telegram within an existing KNX tunnel connection.
 """
+import logging
+
 from xknx.exceptions import CouldNotParseKNXIP, UnsupportedCEMIMessage
 
 from .body import KNXIPBody
 from .cemi_frame import CEMIFrame, CEMIMessageCode
 from .knxip_enum import KNXIPServiceType
 
+logger = logging.getLogger("xknx.log")
+
 
 class TunnellingRequest(KNXIPBody):
     """Representation of a KNX Tunnelling Request."""
@@ -19,14 +23,23 @@ class TunnellingRequest(KNXIPBody):
 
     HEADER_LENGTH = 4
 
-    def __init__(self, xknx):
+    def __init__(
+        self,
+        xknx,
+        communication_channel_id: int = 1,
+        sequence_counter: int = 0,
+        cemi: CEMIFrame = None,
+    ):
         """Initialize TunnellingRequest object."""
         super().__init__(xknx)
 
-        self.communication_channel_id = 1
-        self.sequence_counter = 0
-        self.cemi = CEMIFrame(xknx)
-        self.cemi.code = CEMIMessageCode.L_Data_REQ
+        self.communication_channel_id = communication_channel_id
+        self.sequence_counter = sequence_counter
+        self.cemi = (
+            cemi
+            if cemi is not None
+            else CEMIFrame(xknx, code=CEMIMessageCode.L_Data_REQ)
+        )
 
     def calculated_length(self):
         """Get length of KNX/IP body."""
@@ -49,7 +62,7 @@ class TunnellingRequest(KNXIPBody):
         try:
             pos += self.cemi.from_knx(raw[pos:])
         except UnsupportedCEMIMessage as unsupported_cemi_err:
-            self.xknx.logger.warning("CEMI not supported: %s", unsupported_cemi_err)
+            logger.warning("CEMI not supported: %s", unsupported_cemi_err)
             # Set cemi to None - this is checked in Tunnel() to send Ack even for unsupported CEMI messages.
             self.cemi = None
             pos += len(raw)
